PermissionBuilder

Struct PermissionBuilder 

pub struct PermissionBuilder { /* private fields */ }
Builder for Lambda function permissions.

Creates permission resources that allow other AWS services to invoke a Lambda function. See https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-lambda-permission.html

Implementations

Source

impl PermissionBuilder

pub fn new<R: Into<String>>( id: &str, action: LambdaPermissionAction, function_name: Value, principal: R, ) -> Self

Creates a new permission builder for a Lambda function.

Arguments
  • id - Unique identifier for the permission resource
  • action - Lambda action to allow (e.g., “lambda:InvokeFunction”)
  • function_name - Reference to the Lambda function
  • principal - AWS service or account that will be granted permission
pub fn source_arn(self, arn: Value) -> Self

pub fn current_account(self) -> Self

pub fn build(self, stack_builder: &mut StackBuilder) -> PermissionRef