pub struct BucketTiering(pub String, pub u16);Expand description
Specifies the access tier and the number of days until an object is moved to a specific S3 bucket tier.
Recommended Usage
Use the bucket_tiering! macro from rusty-cdk-macros for compile-time validation:
use rusty_cdk_core::wrappers::BucketTiering;
use rusty_cdk_macros::bucket_tiering;
let tiering = bucket_tiering!("DEEP_ARCHIVE_ACCESS", 180);Tuple Fields
0: String1: u16Trait Implementations
Sourceimpl Clone for BucketTiering
impl Clone for BucketTiering
Sourcefn clone(&self) -> BucketTiering
fn clone(&self) -> BucketTiering
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl Freeze for BucketTiering
impl RefUnwindSafe for BucketTiering
impl Send for BucketTiering
impl Sync for BucketTiering
impl Unpin for BucketTiering
impl UnwindSafe for BucketTiering